https://gist.github.com/hofrob/8b1c1e205a0d4c66a680b1fe4bfeba11

This example script shows a significant increase in performance when using a list, tuple or range over a set in python version 3.11.1.
